BandSox

## Active Sandboxes

0

| ID | Resources | Status | Actions
--- | --- | --- | --- | ---

No active sandboxes found.

## Snapshots

Name | Path | Actions
--- | --- | ---

No snapshots available.

### Create Snapshot

Enter a name for this snapshot to save the current state.

Name

### Restore Snapshot

Create a new VM from this snapshot. Resources will match the snapshot state.

New VM Name

### Confirm Action

Are you sure you want to proceed?